@@ -5,9 +5,9 @@ use namespace::autoclean;
 use Scalar::Util qw(openhandle);
 
 extends 'Catalyst::Action';
-use JSON;
+use JSON::MaybeXS qw(JSON);
 
-our $VERSION = '1.15'; # VERSION
+our $VERSION = '1.16'; # VERSION
 
 sub execute {
     my $self = shift;
